@@ -29,6 +29,7 @@ from pygubu.widgets import simpletooltip
 from pygubu.widgets.scrolledframe import ScrolledFrame
 
 from funing.abc import *
+from funing.data.templates import info_template0
 from funing.locale import _
 from funing.path import *
 from funing.settings import *
@@ -80,13 +81,22 @@ class InfoWidget(WidgetABC):
         self.info_template_dir_path_copy_name = "info_template_dir"
         self.info_template_file_exts = [".txt"]
         self.open_info_template_dir_str = _("Open Directory")
+        self.use_default_info_template_str = _("Default")
+
+    def get_initial_info_templates_combobox_values(self):
+        values = [
+            self.open_info_template_dir_str,
+            self.use_default_info_template_str,
+        ]
+        return values
 
     def update_info_templates_combobox(self):
         if not self.info_templates_combobox:
             return
-        self.info_templates_combobox[
-            "values"
-        ] = self.get_info_template_list() + [self.open_info_template_dir_str]
+        self.info_templates_combobox["values"] = (
+            self.get_info_template_list()
+            + self.get_initial_info_templates_combobox_values()
+        )
 
         pass
 
@@ -101,9 +111,14 @@ class InfoWidget(WidgetABC):
                 self.set_info_template_dir_path(
                     self.info_template_dir_path_copy_name, _path
                 )
-
+        if not isinstance(self.info_template_dir_path, str):
+            print(
+                "path should be string, bytes, os.PathLike or integer, "
+                + "not tuple"
+            )
+            return str(Path.home())
         if not os.path.exists(self.info_template_dir_path):
-            print(_("Path does not exist."))
+            print(_("Info template path does not exist."))
             return str(Path.home())
         return self.info_template_dir_path
 
@@ -921,12 +936,21 @@ class InfoWidget(WidgetABC):
             info = f.read()
         return info
 
-    def del_saved_info_by_info_id(self, info_id=None):
+    def del_saved_info_by_info_id(self, info_id=None, _ask=False):
         info_id = info_id or self.get_info_id()
         if not info_id:
             if self.is_test():
                 print(_("'info_id' is None."))
             return
+        if _ask:
+            delete_info = messagebox.askyesno(
+                master=self.root,
+                title=_("Delete information?"),
+                message=_("Do you want to delete saved information?"),
+            )
+            if not delete_info:
+                return
+            pass
         basic_info_path = get_basic_info_path(info_id)
         info_path = get_info_path(info_id)
         image_dir_path = get_image_dir_path(info_id)
@@ -949,7 +973,7 @@ class InfoWidget(WidgetABC):
             if self.is_test():
                 print(_("ACTION isn't 'READ'."))
             return
-        self.del_saved_info_by_info_id()
+        self.del_saved_info_by_info_id(_ask=True)
         pass
 
     def add_button_command(self):
@@ -960,7 +984,7 @@ class InfoWidget(WidgetABC):
     def get_info_template_values(self):
         template_names = self.get_info_template_list()
         # template_names = [ Path(n).stem for n in template_names ]
-        template_names += [self.open_info_template_dir_str]
+        template_names += self.get_initial_info_templates_combobox_values()
         return template_names
 
     def get_info_templates_combobox_x(self):
@@ -1009,8 +1033,17 @@ class InfoWidget(WidgetABC):
         )
         return _exist
 
+    def use_default_info_template(self):
+        content = info_template0
+        self.set_info_text_content(content)
+        pass
+
     def info_template_var_trace_w(self, *args):
         info_template_name = self.info_template_var.get()
+
+        if info_template_name == self.use_default_info_template_str:
+            self.use_default_info_template()
+
         # self.mk_tmsg(f"info_template_name\t{info_template_name}")
         if info_template_name == self.open_info_template_dir_str:
             # self.open_dir(get_info_templates_path())
@@ -1020,7 +1053,8 @@ class InfoWidget(WidgetABC):
                 initialdir=str(Path.home()),
                 mustexist=True,
             )
-            if _path is None:
+            # print(_path,type(_path))
+            if _path is None or _path == () or _path == "":
                 return
             self.set_copy(self.info_template_dir_path_copy_name, _path)
             self.set_info_template_dir_path(_dir=_path, update_ui=True)
